require 'test_helper'
require 'nokogiri'

require 'bob/compiler/block'

class BlocksTest < Minitest::Test
  include FixtureHelpers

  self.fixture_path << '/blocks'

  fixtures.each do |name|
    test "Fixture #{name}" do
      input    = fixture "#{name}.html"
      expected = fixture "#{name}.js"

      assert_equal expected, compile(input)
      assert_predicate @compiled, :valid?
    end
  end

  [" abc ", " !@#abc^& ", "AbC", "&quot;abc&quot;"].each do |identifier|
    test "Invalid identifier: #{identifier.inspect}" do
      compile %{<div bob-block="#{identifier}"></div>}

      assert_predicate @compiled, :valid?
      refute_predicate @compiled, :well_formed?
      assert_predicate @compiled, :warnings?
      refute_predicate @compiled, :errors?

      assert_includes @compiled.warnings.first.message, "does not contain a valid identifier"
      assert_includes @compiled.warnings.first.message, "assuming you meant"
      assert_equal 1, @compiled.warnings.first.line
    end
  end

  ["!@#^& ", "&quot;&quot;"].each do |identifier|
    test "Invalid identifier: #{identifier.inspect}" do
      compile %{<div bob-block="#{identifier}"></div>}

      refute_predicate @compiled, :valid?
      refute_predicate @compiled, :well_formed?
      refute_predicate @compiled, :warnings?
      assert_predicate @compiled, :errors?

      assert_includes @compiled.errors.first.message, "does not contain a valid identifier"
      assert_equal 1, @compiled.errors.first.line
    end
  end

  ["", "  \t "].each do |identifier|
    test "Blank identifier: #{identifier.inspect}" do
      compile %{<div bob-block="#{identifier}"></div>}

      refute_predicate @compiled, :valid?
      refute_predicate @compiled, :well_formed?
      refute_predicate @compiled, :warnings?
      assert_predicate @compiled, :errors?

      assert_includes @compiled.errors.first.message, "cannot be blank"
      assert_equal 1, @compiled.errors.first.line
    end
  end

  test "Illegal substitution" do
    compile %[<div bob-block="zomg">{{ not valid }}</div>]

    assert_predicate @compiled, :valid?
    refute_predicate @compiled, :well_formed?
    assert_predicate @compiled, :warnings?
    refute_predicate @compiled, :errors?

    assert_includes @compiled.warnings.first.message, "invalid substitution"
    assert_equal 1, @compiled.warnings.first.line
  end

  private
    def compile(str)
      fragment = Nokogiri::HTML::DocumentFragment.parse(str)
      @compiled = Bob::Compiler::Block.new(fragment.children.first)
      @compiled.result
    end
end
