require 'test_helper'
require 'nokogiri'

require 'bob/compiler/layout'

class LayoutsTest < Minitest::Test
  include FixtureHelpers

  self.fixture_path << '/layout'

  fixtures.each do |name|
    test "Fixture #{name}" do
      input    = fixture "#{name}.html"
      expected = fixture "#{name}.js"

      assert_equal expected, compile(input)
      assert_predicate @compiled, :valid?
    end
  end

  test "Container node" do
    compile <<-HTML
      <html>
        <body>
          <div>Not container</div>
          <div bob-container>Container node</div>
          <div>Also not container</div>
        </body>
      </html>
    HTML

    assert_equal "Container node", @compiled.container.text
    assert_predicate @compiled, :valid?
  end

  test "Missing container" do
    compile <<-HTML
      <html>
        <body>
          <div>Not container</div>
          <div>Also not container</div>
        </body>
      </html>
    HTML

    refute_predicate @compiled, :valid?
    refute_predicate @compiled, :well_formed?
    refute_predicate @compiled, :warnings?
    assert_predicate @compiled, :errors?
  end

  test "Multiple containers" do
    compile <<-HTML
      <html>
        <body>
          <div>Not container</div>
          <div bob-container>Container 1</div>
          <div bob-container>Container 2</div>
          <div bob-container>Container 3</div>
        </body>
      </html>
    HTML

    assert_predicate @compiled, :valid?
    refute_predicate @compiled, :well_formed?
    assert_predicate @compiled, :warnings?
    refute_predicate @compiled, :errors?
  end

  private
    def compile(str)
      doc = Nokogiri::HTML(str)
      @compiled = Bob::Compiler::Layout.new(doc.root)
      @compiled.result
    end
end
