require 'test_helper'
require 'nokogiri'

require 'bob/compiler/template'

class TemplatesTest < Minitest::Test
  include FixtureHelpers

  self.fixture_path << '/templates'

  fixtures.each do |name|
    test "Fixture #{name}" do
      input    = fixture "#{name}.html"
      expected = fixture "#{name}.js"

      assert_equal expected, compile(name, input)
      assert_predicate @compiled, :valid?
    end
  end

  test "Blank document" do
    compile "blank-document", ""

    refute_predicate @compiled, :valid?
    refute_predicate @compiled, :well_formed?
    refute_predicate @compiled, :warnings?
    assert_predicate @compiled, :errors?
  end

  test "Missing container" do
    compile "missing-container", <<-HTML
      <html>
      <body>
        <div>Not container</div>
        <div>Also not container</div>
      </body>
      </html>
    HTML

    refute_predicate @compiled, :valid?
    refute_predicate @compiled, :well_formed?
    refute_predicate @compiled, :warnings?
    assert_predicate @compiled, :errors?
  end

  private
    def compile(name, str)
      @compiled = Bob::Compiler::Template.new(name, str)
      @compiled.result
    end
end
