require 'minitest/autorun'
require 'minitest/pride'

require 'active_support'
require 'active_support/concern'
require 'active_support/core_ext/class/attribute'
require 'active_support/testing/declarative'

# Get rid of the annoying warning
I18n.enforce_available_locales = true

class Minitest::Test
  extend ActiveSupport::Testing::Declarative
end

module FixtureHelpers
  extend ActiveSupport::Concern

  included do
    class_attribute :fixture_path
    class_attribute :fixture_cache

    self.fixture_path  = File.expand_path('../fixtures', __FILE__)
    self.fixture_cache = {}
  end

  module ClassMethods
    def fixture(filename)
      fixture_cache[filename] ||= File.read(File.join(fixture_path, filename))
    end

    def fixtures
      Dir.glob(File.join(fixture_path, '*.js')).map do |filename|
        File.basename(filename).gsub(/\.js\z/, '')
      end
    end
  end

  private
    def fixture(filename)
      self.class.fixture(filename)
    end
end
